# py_to_mindustry

Translator from Python to Mindustry processor language

The following features are currently supported:
- All built-in commands in Mindustry
- Arbitrarily complex mathematical and logical expressions
- Following keywords: `False`, `None`, `True`, `and`, `break`, `continue`, `def`, `elif`, `else`, `for`, `global`, `if`, `is`, `lambda`, `not`, `or`, `pass`, `return`, `while`

# Usage

```
python -m pip install py_to_mindustry
```
```py
from py_to_mindustry import py_to_mindustry
print(py_to_mindustry(your_program_text))
```

# How to use Mindustry commands

...
